==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebPinningConfigDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPinningConfigDescription } from "./WebPinningConfigDescription";
/**
 * @hidden
 */
var WebPinningConfigDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPinningConfigDescriptionMetadata, _super);
    function WebPinningConfigDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPinningConfigDescriptionMetadata.b = function (a) {
        if (WebPinningConfigDescriptionMetadata.a == null) {
            WebPinningConfigDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPinningConfigDescriptionMetadata.c(WebPinningConfigDescriptionMetadata.a);
        }
        if (a.k(WebPinningConfigDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebPinningConfigDescriptionMetadata.a);
    };
    WebPinningConfigDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PinningConfig");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Columns", "ExportedType:string:ColumnPinningPosition");
        a.item("Columns@names", "Start;End");
        a.item("Rows", "ExportedType:string:RowPinningPosition");
        a.item("Rows@names", "Top;Bottom");
    };
    WebPinningConfigDescriptionMetadata.d = function (a) {
        WebPinningConfigDescriptionMetadata.b(a);
        a.ad("WebPinningConfig", function () { return new WebPinningConfigDescription(); });
        a.ac("WebPinningConfig", WebPinningConfigDescriptionMetadata.a);
    };
    WebPinningConfigDescriptionMetadata.$t = markType(WebPinningConfigDescriptionMetadata, 'WebPinningConfigDescriptionMetadata');
    WebPinningConfigDescriptionMetadata.a = null;
    return WebPinningConfigDescriptionMetadata;
}(Base));
export { WebPinningConfigDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebPinningConfigDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPinningConfigDescription } from "./WebPinningConfigDescription";
/**
 * @hidden
 */
var WebPinningConfigDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPinningConfigDescriptionMetadata, _super);
    function WebPinningConfigDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPinningConfigDescriptionMetadata.b = function (a) {
        if (WebPinningConfigDescriptionMetadata.a == null) {
            WebPinningConfigDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPinningConfigDescriptionMetadata.c(WebPinningConfigDescriptionMetadata.a);
        }
        if (a.k(WebPinningConfigDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPinningConfigDescriptionMetadata.a);
    };
    WebPinningConfigDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PinningConfig");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("__isTSPlainInterface", "Boolean");
        a.item("Columns", "ExportedType:string:ColumnPinningPosition");
        a.item("Columns@names", "Start;End");
        a.item("Rows", "ExportedType:string:RowPinningPosition");
        a.item("Rows@names", "Top;Bottom");
    };
    WebPinningConfigDescriptionMetadata.d = function (a) {
        WebPinningConfigDescriptionMetadata.b(a);
        a.ae("WebPinningConfig", function () { return new WebPinningConfigDescription(); });
        a.ad("WebPinningConfig", WebPinningConfigDescriptionMetadata.a);
    };
    WebPinningConfigDescriptionMetadata.$t = markType(WebPinningConfigDescriptionMetadata, 'WebPinningConfigDescriptionMetadata');
    WebPinningConfigDescriptionMetadata.a = null;
    return WebPinningConfigDescriptionMetadata;
}(Base));
export { WebPinningConfigDescriptionMetadata };
